# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKOptimizersv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkLBFGSOptimizerBasev4Python
else:
    import _itkLBFGSOptimizerBasev4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkObjectToObjectMetricBasePython
import itk.itkOptimizerParametersPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkArrayPython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython
import itk.itkLBFGSOptimizerBaseHelperv4Python
import itk.vnl_cost_functionPython
import itk.vnl_unary_functionPython
import itk.itkVnlTypesPython
import itk.itkSingleValuedNonLinearVnlOptimizerv4Python
import itk.itkObjectToObjectOptimizerBasePython
import itk.itkOptimizerParameterScalesEstimatorPython
class itkLBFGSOptimizerBasev4vnl_lbfgs(itk.itkSingleValuedNonLinearVnlOptimizerv4Python.itkSingleValuedNonLinearVnlOptimizerv4):
    r"""Proxy of C++ itkLBFGSOptimizerBasev4vnl_lbfgs class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOptimizer(self):
        r"""GetOptimizer(self) -> itkLBFGSOptimizerBaseHelperv4vnl_lbfgs"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_GetOptimizer(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_StartOptimization(self, doOnlyInitialization)

    def SetTrace(self, flag):
        r"""
        SetTrace(self, flag)

        Parameters
        ----------
        flag: bool

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_SetTrace(self, flag)

    def GetTrace(self):
        r"""GetTrace(self) -> bool"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_GetTrace(self)

    def TraceOn(self):
        r"""TraceOn(self)"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_TraceOn(self)

    def TraceOff(self):
        r"""TraceOff(self)"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_TraceOff(self)

    def SetMaximumNumberOfFunctionEvaluations(self, n):
        r"""
        SetMaximumNumberOfFunctionEvaluations(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_SetMaximumNumberOfFunctionEvaluations(self, n)

    def GetMaximumNumberOfFunctionEvaluations(self):
        r"""GetMaximumNumberOfFunctionEvaluations(self) -> unsigned int"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_GetMaximumNumberOfFunctionEvaluations(self)

    def SetGradientConvergenceTolerance(self, f):
        r"""
        SetGradientConvergenceTolerance(self, f)

        Parameters
        ----------
        f: double

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_SetGradientConvergenceTolerance(self, f)

    def GetGradientConvergenceTolerance(self):
        r"""GetGradientConvergenceTolerance(self) -> double"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_GetGradientConvergenceTolerance(self)
    __swig_destroy__ = _itkLBFGSOptimizerBasev4Python.delete_itkLBFGSOptimizerBasev4vnl_lbfgs

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLBFGSOptimizerBasev4vnl_lbfgs

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_cast(obj)

# Register itkLBFGSOptimizerBasev4vnl_lbfgs in _itkLBFGSOptimizerBasev4Python:
_itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgs_swigregister(itkLBFGSOptimizerBasev4vnl_lbfgs)
class itkLBFGSOptimizerBasev4vnl_lbfgsb(itk.itkSingleValuedNonLinearVnlOptimizerv4Python.itkSingleValuedNonLinearVnlOptimizerv4):
    r"""Proxy of C++ itkLBFGSOptimizerBasev4vnl_lbfgsb class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOptimizer(self):
        r"""GetOptimizer(self) -> itkLBFGSOptimizerBaseHelperv4vnl_lbfgsb"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_GetOptimizer(self)

    def StartOptimization(self, doOnlyInitialization=False):
        r"""
        StartOptimization(self, doOnlyInitialization=False)

        Parameters
        ----------
        doOnlyInitialization: bool

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_StartOptimization(self, doOnlyInitialization)

    def SetTrace(self, flag):
        r"""
        SetTrace(self, flag)

        Parameters
        ----------
        flag: bool

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_SetTrace(self, flag)

    def GetTrace(self):
        r"""GetTrace(self) -> bool"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_GetTrace(self)

    def TraceOn(self):
        r"""TraceOn(self)"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_TraceOn(self)

    def TraceOff(self):
        r"""TraceOff(self)"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_TraceOff(self)

    def SetMaximumNumberOfFunctionEvaluations(self, n):
        r"""
        SetMaximumNumberOfFunctionEvaluations(self, n)

        Parameters
        ----------
        n: unsigned int

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_SetMaximumNumberOfFunctionEvaluations(self, n)

    def GetMaximumNumberOfFunctionEvaluations(self):
        r"""GetMaximumNumberOfFunctionEvaluations(self) -> unsigned int"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_GetMaximumNumberOfFunctionEvaluations(self)

    def SetGradientConvergenceTolerance(self, f):
        r"""
        SetGradientConvergenceTolerance(self, f)

        Parameters
        ----------
        f: double

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_SetGradientConvergenceTolerance(self, f)

    def GetGradientConvergenceTolerance(self):
        r"""GetGradientConvergenceTolerance(self) -> double"""
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_GetGradientConvergenceTolerance(self)
    __swig_destroy__ = _itkLBFGSOptimizerBasev4Python.delete_itkLBFGSOptimizerBasev4vnl_lbfgsb

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLBFGSOptimizerBasev4vnl_lbfgsb

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_cast(obj)

# Register itkLBFGSOptimizerBasev4vnl_lbfgsb in _itkLBFGSOptimizerBasev4Python:
_itkLBFGSOptimizerBasev4Python.itkLBFGSOptimizerBasev4vnl_lbfgsb_swigregister(itkLBFGSOptimizerBasev4vnl_lbfgsb)

